@@ -25,8 +25,8 @@ For more details see:
 
     python -m xdoctest --help
 
-Using the XDoctest Runner Programatically
------------------------------------------
+Using the XDoctest Runner Programmatically
+------------------------------------------
 
 This interface may also be run programmatically using
 ``xdoctest.doctest_module(path)``, which can be placed in the
@@ -102,7 +102,7 @@ def doctest_callable(func):
 
 def doctest_module(module_identifier=None, command=None, argv=None, exclude=[],
                    style='auto', verbose=None, config=None, durations=None,
-                   analysis='static'):
+                   analysis='auto'):
     """
     Executes requestsed google-style doctests in a package or module.
     Main entry point into the testing framework.
@@ -381,7 +381,7 @@ def _print_summary_report(run_summary, parse_warnlist, n_seconds,
 
     if failed and len(enabled_examples) > 1:
         # If there is more than one test being run, _log out all the
-        # errors that occured so they are consolidated in a single place.
+        # errors that occurred so they are consolidated in a single place.
         cprint('\n=== Found {} errors ==='.format(len(failed)), 'red')
         for fail_idx, example in enumerate(failed, start=1):
             cprint('--- Error: {} / {} ---'.format(fail_idx, len(failed)), 'red')
@@ -452,7 +452,7 @@ def _run_examples(enabled_examples, verbose, config=None, _log=None):
     failed = []
     warned = []
     times = {}
-    # It is important to raise immediatly within the test to display errors
+    # It is important to raise immediately within the test to display errors
     # returned from multiprocessing. Especially in zero-arg mode
 
     on_error = 'return' if n_total > 1 else 'raise'
@@ -571,24 +571,24 @@ def _update_argparse_cli(add_argument, prefix=None):
         return str.lower(str(x))
 
     add_argument(*('-m', '--modname'), type=str,
-                 help='module name or path. If specified positional modules are ignored',
+                 help='Module name or path. If specified positional modules are ignored',
                  default=None)
 
     add_argument(*('-c', '--command'), type=str,
-                 help='a doctest name or a command (list|all|<callname>). '
+                 help='A doctest name or a command (list|all|<callname>). '
                  'Defaults to all',
                  default=None)
 
     add_argument(*('--style',), type=str,
-                 help='choose the style of doctests that will be parsed',
+                 help='Choose the style of doctests that will be parsed',
                  choices=['auto', 'google', 'freeform'], default='auto')
 
     add_argument(*('--analysis',), type=str,
                  help='How doctests are collected',
-                 choices=['auto', 'static', 'dynamic'], default='static')
+                 choices=['auto', 'static', 'dynamic'], default='auto')
 
     add_argument(*('--durations',), type=int,
-                 help=('specify execution times for slowest N tests.'
+                 help=('Specify execution times for slowest N tests.'
                        'N=0 will show times for all tests'),
                  default=None)
 
