@@ -403,7 +403,7 @@ class TopLevelVisitor(ast.NodeVisitor):
             sourcelines (list): a list of all lines in the file. We assume
                 the docstring exists as a pure string literal in the source.
                 In other words, no postprocessing via split, format, or any
-                other dynamic programatic modification should be made to the
+                other dynamic programmatic modification should be made to the
                 docstrings. Python's docstring extractor assumes this as well.
 
             endpos (int): line position (starting at 0) the docstring ends on.
@@ -644,7 +644,7 @@ def parse_static_calldefs(source=None, fpath=None):
 
     Returns:
         Dict[str, CallDefNode]:
-            maping from callnames to CallDefNodes, which contain
+            mapping from callnames to CallDefNodes, which contain
                info about the item with the doctest.
 
     Example:
@@ -763,11 +763,11 @@ def parse_static_value(key, source=None, fpath=None):
                 if target_id == key:
                     self.value = _parse_static_node_value(node.value)
 
-    sentinal = object()
+    sentinel = object()
     visitor = AssignentVisitor()
-    visitor.value = sentinal
+    visitor.value = sentinel
     visitor.visit(pt)
-    if visitor.value is sentinal:
+    if visitor.value is sentinel:
         raise NameError('No static variable named {!r}'.format(key))
     return visitor.value
 
@@ -841,7 +841,7 @@ def package_modpaths(pkgpath, with_pkg=False, with_mod=True, followlinks=True,
                 break
 
 
-def is_balanced_statement(lines, only_tokens=False):
+def is_balanced_statement(lines, only_tokens=False, reraise=0):
     r"""
     Checks if the lines have balanced braces and quotes.
 
@@ -900,6 +900,13 @@ def is_balanced_statement(lines, only_tokens=False):
         >>> ]
         >>> print('\n'.join(source_parts))
         >>> assert is_balanced_statement(source_parts)
+
+    Doctest:
+        >>> lines = ['try: raise Exception']
+        >>> is_balanced_statement(lines, only_tokens=1)
+        True
+        >>> is_balanced_statement(lines, only_tokens=0)
+        False
     """
     # Only iterate through non-empty lines otherwise tokenize will stop short
     lines = list(lines)
@@ -912,11 +919,15 @@ def is_balanced_statement(lines, only_tokens=False):
     except tokenize.TokenError as ex:
         message = ex.args[0]
         if message.startswith('EOF in multi-line'):
+            if reraise:
+                raise
             return False
         raise
     except IndentationError as ex:
         message = ex.args[0]
         if message.startswith('unindent does not match any outer indentation'):
+            if reraise:
+                raise
             return False
         raise
     else:
@@ -932,8 +943,9 @@ def is_balanced_statement(lines, only_tokens=False):
                 # text = dedent(text)
                 six_axt_parse(text)
             except SyntaxError:
+                if reraise:
+                    raise
                 return False
-
         return True
 
 
