@@ -44,7 +44,7 @@ class TeeStringIO(io.StringIO):
         """
         Returns true of the redirect is a terminal.
 
-        Notes:
+        Note:
             Needed for IPython.embed to work properly when this class is used
             to override stdout / stderr.
         """
@@ -110,13 +110,13 @@ class CaptureStdout(CaptureStream):
     Context manager that captures stdout and stores it in an internal stream
 
     Args:
-        supress (bool, default=True):
+        suppress (bool, default=True):
             if True, stdout is not printed while captured
         enabled (bool, default=True):
             does nothing if this is False
 
     Example:
-        >>> self = CaptureStdout(supress=True)
+        >>> self = CaptureStdout(suppress=True)
         >>> print('dont capture the table flip (╯°□°）╯︵ ┻━┻')
         >>> with self:
         ...     text = 'capture the heart ♥'
@@ -126,22 +126,30 @@ class CaptureStdout(CaptureStream):
         >>> assert self.text == text + '\n', 'failed capture text'
 
     Example:
-        >>> self = CaptureStdout(supress=False)
+        >>> self = CaptureStdout(suppress=False)
         >>> with self:
         ...     print('I am captured and printed in stdout')
         >>> assert self.text.strip() == 'I am captured and printed in stdout'
 
     Example:
-        >>> self = CaptureStdout(supress=True, enabled=False)
+        >>> self = CaptureStdout(suppress=True, enabled=False)
         >>> with self:
         ...     print('dont capture')
         >>> assert self.text is None
     """
-    def __init__(self, supress=True, enabled=True):
+    def __init__(self, suppress=True, enabled=True, **kwargs):
+        _misspelled_varname = 'supress'
+        if _misspelled_varname in kwargs:  # nocover
+            import warnings
+            warnings.warn(
+                'Argument of CaptureStdout {} is misspelled and deprecated. Use suppress instead'.format(_misspelled_varname), DeprecationWarning)
+            suppress = kwargs.pop(_misspelled_varname)
+            if len(kwargs) > 0:
+                raise ValueError('unexpected args: {}'.format(kwargs))
         self.enabled = enabled
-        self.supress = supress
+        self.suppress = suppress
         self.orig_stdout = sys.stdout
-        if supress:
+        if suppress:
             redirect = None
         else:
             redirect = self.orig_stdout
